@@ -64,9 +64,9 @@ class GeoArray(object):
     some functions for quickly visualizing the data as a map, a simple image or an interactive image.
     """
 
-    def __init__(self, path_or_array, geotransform=None, projection=None, bandnames=None, nodata=None, progress=True,
-                 q=False):
-        # type: (Union[str, np.ndarray, GeoArray], tuple, str, list, float, bool, bool) -> None
+    def __init__(self, path_or_array, geotransform=None, projection=None, bandnames=None, nodata=None, basename='',
+                 progress=True, q=False):
+        # type: (Union[str, np.ndarray, GeoArray], tuple, str, list, float, str, bool, bool) -> None
         """Get an instance of GeoArray.
 
         :param path_or_array:   a numpy.ndarray or a valid file path
@@ -76,6 +76,7 @@ class GeoArray(object):
         :param bandnames:       names of the bands within the input array, e.g. ['mask_1bit', 'mask_clouds'],
                                 (default: ['B1', 'B2', 'B3', ...])
         :param nodata:          nodata value
+        :param basename:        a short base name of the dataset (e.g., used in some status messages)
         :param progress:        show progress bars (default: True)
         :param q:               quiet mode (default: False)
         """
@@ -99,16 +100,18 @@ class GeoArray(object):
             self.geotransform = geotransform or self.geotransform
             self.projection = projection or self.projection
             self.bandnames = bandnames or list(self.bandnames.keys())
+            self.basename = basename or self.basename
             self._nodata = nodata if nodata is not None else self._nodata
             self.progress = False if progress is False else self.progress
-            self.q = q if q is not None else self.q
+            self.q = q or self.q
 
         else:
             self._initParams = dict([x for x in locals().items() if x[0] != "self"])
             self.arg = path_or_array
             self._arr = path_or_array if isinstance(path_or_array, np.ndarray) else None
             self.filePath = path_or_array if isinstance(path_or_array, str) and path_or_array else None
-            self.basename = os.path.splitext(os.path.basename(self.filePath))[0] if not self.is_inmem else 'IN_MEM'
+            basename_default = os.path.splitext(os.path.basename(self.filePath))[0] if not self.is_inmem else 'IN_MEM'
+            self.basename = basename or basename_default
             self.progress = progress
             self.q = q
             self._arr_cache = None  # dict containing key 'pos' and 'arr_cached'
@@ -1030,9 +1033,6 @@ class GeoArray(object):
         #########################################
 
         try:
-            # disable to write separate metadata XML files
-            os.environ['GDAL_PAM_ENABLED'] = 'NO'
-
             # ENVI #
             ########
             if fmt == 'ENVI':
@@ -1074,9 +1074,14 @@ class GeoArray(object):
                     ds_out.SetDescription(envi_metadict['description'])
 
                 ds_out.FlushCache()
-                # gdal.Unlink(out_path + '.aux.xml')
+
+                # NOTE: In case of ENVI format and GDAL_PAM_ENABLED=NO, the metadata is not written
+                gdal.Unlink(out_path + '.aux.xml')
 
             else:
+                # disable to write separate metadata XML files
+                os.environ['GDAL_PAM_ENABLED'] = 'NO'
+
                 ds_out = ds_src
 
                 # set metadata
